@@ -14,11 +14,14 @@ from django.template import RequestContext
 from django.core.serializers.json import DjangoJSONEncoder
 from django.core.urlresolvers import reverse
 from django.utils.safestring import mark_safe
+from django.contrib.auth.decorators import login_required
+from django.contrib import messages
 
 from geonode.base.models import SpatialRepresentationType, TopicCategory
 from geonode.layers.metadata import set_metadata, sniff_date
 from geonode.layers.models import Layer
-from geonode.layers.views import _resolve_layer, _PERMISSION_MSG_METADATA, layer_detail
+from geonode.layers.views import _resolve_layer, \
+    _PERMISSION_MSG_METADATA, layer_detail
 from geonode.utils import http_client, _get_basic_auth_info, json_response
 from geonode.people.enumerations import ROLE_VALUES
 from geonode.people.models import Profile, Role
@@ -26,10 +29,13 @@ from geonode.base.enumerations import ALL_LANGUAGES, \
     HIERARCHY_LEVELS, UPDATE_FREQUENCIES, \
     DEFAULT_SUPPLEMENTAL_INFORMATION, LINK_TYPES
 
+from geosk.skregistration.models import SkRegistration
 from geosk.skregistration.views import get_key
 
 from geosk.mdtools.forms import UploadMetadataFileForm
-from geosk.mdtools.models import ResponsiblePartyScope, MultiContactRole, SCOPE_VALUES
+from geosk.mdtools.models import ResponsiblePartyScope, MultiContactRole, \
+    SCOPE_VALUES
+from geosk import UnregisteredSKException
 
 EDI_MAP_SPATIALREPRESENTATIONTYPE = {
     'dataStore': 'http://www.rndt.gov.it/codelists/MD_SpatialRepresentationTypeCode/items/001',
@@ -48,6 +54,7 @@ def get_datetype(ita):
             return neutral
     return None
 
+
 def get_topic_category(ita):
     TOPIC_CATEGORY = {
         'inlandWaters': 'Acque interne',
@@ -82,7 +89,7 @@ def rndteditor(request, layername):
         'template': 'RNDT',
         'version': '2.00',
         'parameters': "{}"
-        }    
+        }
 
     fileid = layer.mdextension.fileid
     pars = {}
@@ -115,11 +122,11 @@ def rndteditor(request, layername):
             'referencesystem': layer.srid.split(':')[1],
             }
 
-    
+
     js_pars = json.dumps(pars, cls=DjangoJSONEncoder)
 
     queryStringValues['parameters'] = json.dumps(pars, cls=DjangoJSONEncoder)
-    
+
     js_queryStringValues = json.dumps(queryStringValues)
     return render_to_response(
         'mdtools/rndt.html',
@@ -128,98 +135,109 @@ def rndteditor(request, layername):
                 'queryStringValues': mark_safe(js_queryStringValues)
                 })
         )
-    
-def rndtproxy(request, layername):
-    layer = _resolve_layer(request, layername, 'layers.change_layer', _PERMISSION_MSG_METADATA)
 
+def _ediml2rndt(ediml):
+    if SkRegistration.objects.get_current() is None:
+        raise UnregisteredSKException('You must register the GET-IT before a Metadata')
     service = settings.RITMARE['MDSERVICE'] + 'postMetadata'
-
     headers = {'api_key': get_key(),
                'Content-Type': 'application/xml',
                }
-
-    r = requests.post(service, data=request.raw_post_data,  headers=headers, verify=False)
+    r = requests.post(service, data=ediml,  headers=headers, verify=False)
     if r.status_code == 200:
         rndt = r.text.encode('utf8')
-        # extract fileid
-        ediml = etree.fromstring(request.raw_post_data)
-        fileid = ediml.find('fileId').text
-
-        # new fileid must be equal to the old one
-        if layer.mdextension.fileid is not None:
-            if int(layer.mdextension.fileid) != int(fileid):
-                return json_response(errors='New fileid (%s) is different from the old one (%s)' % (fileid, layer.mdextension.fileid), 
-                                     status=500)
-        else:
-            layer.mdextension.fileid = fileid
+        return rndt
     else:
-        return json_response(errors='Cannot create RNDT', 
-                             status=500)
+        return False
 
+def _get_fileid(ediml):
+    ediml = etree.fromstring(ediml)
+    return ediml.find('fileId').text
+
+def ediml(request, layername):
+    layer = _resolve_layer(request, layername, 'layers.change_layer', _PERMISSION_MSG_METADATA)
+    ediml = layer.mdextension.elements_xml
+    return HttpResponse(ediml, mimetype="text/xml")
+
+def rndt(request, layername):
+    layer = _resolve_layer(request, layername, 'layers.change_layer', _PERMISSION_MSG_METADATA)
+    rndt = layer.mdextension.rndt_xml
+    return HttpResponse(rndt, mimetype="text/xml")
+
+
+def rndtproxy(request, layername):
+    layer = _resolve_layer(request, layername, 'layers.change_layer', _PERMISSION_MSG_METADATA)
+    ediml = request.raw_post_data
     try:
-        vals, keywords = rndt2dict(etree.fromstring(rndt))
-        errors = _post_validate(vals)
-        if len(errors) > 0:
-            return json_response(exception=errors, status=500)
-        _mdimport(layer, vals, keywords, rndt)
+        rndt = _ediml2rndt(ediml)
+    except UnregisteredSKException, e:
+        return json_response(errors=e.message,
+                             status=500)
+    if not rndt:
+        return json_response(errors='Cannot create RNDT',
+                             status=500)
+    try:
+        _savelayermd(layer, rndt, ediml)
     except Exception as e:
         return json_response(exception=e, status=500)
-        
-    # save rndt & edi xml
-    layer.mdextension.md_language = vals['md_language']
-    layer.mdextension.md_date = vals['md_date'] if vals['md_date'] is not None else layer.date 
-    layer.mdextension.rndt_xml = rndt
-    layer.mdextension.elements_xml = request.raw_post_data
-    layer.mdextension.save()
+
     return json_response(body={'success':True,'redirect': reverse('layer_detail', args=(layer.typename,))})
     # return HttpResponseRedirect()
 
-
 def _post_validate(vals):
     errors = []
     # check required fields
     # required = [f.name for f in Layer._meta.fields if not f.blank]
     # required = ['uuid', 'title', 'date', 'date_type', 'language', 'supplemental_information']
-    required = ['uuid', 'title', 'date', 'date_type', 'language']
+    # Uuid could be None
+    # required = ['uuid', 'title', 'date', 'date_type', 'language']
+    required = ['title', 'date', 'date_type', 'language']
     for r in required:
         if r not in vals.keys():
             errors.append(r)
     return errors
-    
 
-def mdimport(request, template='mdtools/upload_metadata.html'):
+def importediml(request, template='mdtools/upload_metadata.html'):
     if request.method == 'POST':
         form = UploadMetadataFileForm(request.POST, request.FILES)
         if form.is_valid():
-            # response_data = set_metadata(request.FILES['file'].read())
-            # return HttpResponse(json.dumps(response_data, 
-            #                                sort_keys=True,
-            #                                indent=4, 
-            #                                separators=(',', ': '),
-            #                                cls=DjangoJSONEncoder), 
-            #                     content_type="application/json")
-            layerid = form.cleaned_data['layerid']
-            layer = Layer.objects.get(pk=layerid)
-
-            xml = request.FILES['file'].read()
-            # response_data = _parse_metadata(xml)
-            vals, keywords = rndt2dict(etree.fromstring(xml))
-            response_data = _mdimport(layer, vals, keywords, xml)
-            
-            return HttpResponse(json.dumps(response_data, 
-                                           default=lambda o: o.__dict__, 
-                                           sort_keys=True,
-                                           indent=4, 
-                                           separators=(',', ': '),
-                                           cls=DjangoJSONEncoder), 
-                                content_type="application/json")
+            layername = Layer.objects.get(pk=form.cleaned_data['layer']).typename
+            layer = _resolve_layer(request, layername, 'layers.change_layer', _PERMISSION_MSG_METADATA)
+            ediml = request.FILES['file'].read()
+            try:
+                rndt = _ediml2rndt(ediml)
+            except UnregisteredSKException, e:
+                messages.add_message(request, messages.ERROR, e)
+            if not rndt:
+                messages.add_message(request, messages.ERROR, 'Cannot get RNDT.')
+            try:
+                _savelayermd(layer, rndt, ediml)
+                messages.add_message(request, messages.SUCCESS, 'Metadata Uploaded')
+            except Exception as e:
+                messages.add_message(request, messages.ERROR, e)
 
     else:
         form = UploadMetadataFileForm()
     return render_to_response(template,
                               RequestContext(request, {'form': form}))
 
+def importrndt(request, template='mdtools/upload_metadata.html'):
+    if request.method == 'POST':
+        form = UploadMetadataFileForm(request.POST, request.FILES)
+        if form.is_valid():
+            layername = Layer.objects.get(pk=form.cleaned_data['layer']).typename
+            layer = _resolve_layer(request, layername, 'layers.change_layer', _PERMISSION_MSG_METADATA)
+            rndt = request.FILES['file'].read()
+            try:
+                _savelayermd(layer, rndt, None)
+                messages.add_message(request, messages.SUCCESS, 'Metadata Uploaded')
+            except Exception as e:
+                messages.add_message(request, messages.ERROR, e)
 
+    else:
+        form = UploadMetadataFileForm()
+    return render_to_response(template,
+                              RequestContext(request, {'form': form}))
 
 def _parse_metadata(xml):
     try:
@@ -231,7 +249,20 @@ def _parse_metadata(xml):
     mdata.xml = None
     return mdata
 
-def _mdimport(layer, vals, keywords, xml):
+def _savelayermd(layer, rndt, ediml, version='1'):
+    if ediml:
+        fileid = _get_fileid(ediml)
+        # new fileid must be equal to the old one
+        if layer.mdextension.fileid is not None:
+            if int(layer.mdextension.fileid) != int(fileid):
+                raise Exception('New fileid (%s) is different from the old one (%s)' % (fileid, layer.mdextension.fileid))
+        layer.mdextension.fileid = fileid
+
+    vals, keywords = rndt2dict(etree.fromstring(rndt))
+    errors = _post_validate(vals)
+    if len(errors) > 0:
+        raise Exception(errors)
+
     # print >>sys.stderr, 'VALS', vals
     # set taggit keywords
     layer.keywords.clear()
@@ -253,7 +284,17 @@ def _mdimport(layer, vals, keywords, xml):
         setattr(layer, key, value)
 
     layer.save()
-    return layer
+
+    # save rndt & edi xml
+    layer.mdextension.md_language = vals['md_language']
+    layer.mdextension.md_date = vals['md_date'] if vals['md_date'] is not None else layer.date
+    layer.mdextension.rndt_xml = rndt
+    layer.mdextension.ediversion = version
+    if ediml:
+        layer.mdextension.elements_xml = ediml
+    layer.mdextension.save()
+
+    return True
 
 def _set_contact_role_scope(scope, contacts, resource):
     scope = _get_or_create_scope(scope)
@@ -291,7 +332,7 @@ def _get_or_create_profile(contact):
     # some cleaning
     fields = Profile._meta.get_all_field_names()
     _defaults= {k:v for k, v in contact.items() if k in fields}
-    del(_defaults['email']) # 
+    del(_defaults['email']) #
     # create profile
     profile, is_created = Profile.objects.get_or_create(defaults=_defaults, email=_email)
     return profile
@@ -331,15 +372,16 @@ def rndt2dict(exml):
 
     mdata = EDI_Metadata(exml)
 
-    # metadata 
-    vals['uuid'] = mdata.identifier
+    # metadata
+    if mdata.identifier is not None:
+        vals['uuid'] = mdata.identifier
     vals['md_language'] = mdata.languagecode
     vals['md_date'] = sniff_date(mdata.datestamp) if mdata.datestamp is not None else None
 
     vals['spatial_representation_type'] = mdata.hierarchy
 
     if hasattr(mdata, 'identification'):
-        # 
+        #
         if len(mdata.identification.date) > 0:
             vals['date'] = sniff_date(mdata.identification.date[0].date) if mdata.identification.date[0].date is not None else None
             vals['date_type'] = get_datetype(mdata.identification.date[0].type) if mdata.identification.date[0].type is not None else None
@@ -353,10 +395,8 @@ def rndt2dict(exml):
         vals['purpose'] = mdata.identification.purpose
         vals['supplemental_information'] = mdata.identification.supplementalinformation if mdata.identification.supplementalinformation is not None else DEFAULT_SUPPLEMENTAL_INFORMATION
 
-        # vals['temporal_extent_start'] = \
-        #     mdata.identification.temporalextent_start
-        # vals['temporal_extent_end'] = \
-        #     mdata.identification.temporalextent_end
+        vals['temporal_extent_start'] = mdata.identification.temporalextent_start
+        vals['temporal_extent_end'] = mdata.identification.temporalextent_end
 
         if len(mdata.identification.topiccategory) > 0:
             vals['topic_category'] = get_topic_category(mdata.identification.topiccategory[0])
@@ -384,7 +424,7 @@ def rndt2dict(exml):
                 c['onlineresource'] = c['onlineresource'].__dict__
             citation_contact.append(c)
         vals['citation_contact'] = citation_contact
-                
+
         md_contact = []
         for c in mdata.contact:
             c = c.__dict__
@@ -402,16 +442,48 @@ def rndt2dict(exml):
         vals['identification_contact'] = identification_contact
 
         distributor_contact = []
-        for d in mdata.distribution.distributor:
-            c = d.contact
-            c = c.__dict__
-            if c['onlineresource'] is not None:
-                c['onlineresource'] = c['onlineresource'].__dict__
-            distributor_contact.append(c)
-        vals['distributor_contact'] = distributor_contact
+        if hasattr(mdata.distribution, 'distributor'):
+            for d in mdata.distribution.distributor:
+                c = d.contact
+                c = c.__dict__
+                if c['onlineresource'] is not None:
+                    c['onlineresource'] = c['onlineresource'].__dict__
+                distributor_contact.append(c)
+            vals['distributor_contact'] = distributor_contact
 
 
     if mdata.dataquality is not None:
         vals['data_quality_statement'] = mdata.dataquality.lineage
 
     return [vals, keywords]
+
+# TODO: move on ediproxy app
+# ediml version 2
+@login_required
+def ediproxy_importmd(request, layername):
+    layer = _resolve_layer(request, layername, 'layers.change_layer', _PERMISSION_MSG_METADATA)
+    isoml = request.POST.get('generatedXml').encode('utf8')
+    ediml = request.POST.get('ediml').encode('utf8')
+    edimlid = request.POST.get('edimlid')
+    try:
+        _savelayermd(layer, isoml, ediml, version='2')
+    except Exception as e:
+        return json_response(exception=e, status=500)
+    return json_response(body={'success':True})
+
+# fare una class base view
+# e spostare in una nuova funzione rest
+# def load_isoedimlid(request, layername):
+
+# def load_isoediml(request, layername):
+#     layer = _resolve_layer(request, layername, 'layers.change_layer', _PERMISSION_MSG_METADATA)
+#     ediml = request.raw_post_data
+
+#         _savelayermd(layer, rndt, ediml)
+#     except Exception as e:
+#         return json_response(exception=e, status=500)
+
+#     return json_response(body={'success':True,'redirect': reverse('layer_detail', args=(layer.typename,))})
+#     # return HttpResponseRedirect()
+
+# # def load_
