@@ -1,5 +1,20 @@
+function ValidURL(str) {
+      var pattern = new RegExp('^(https?:\\/\\/)?'+ // protocol
+  '((([a-z\\d]([a-z\\d-]*[a-z\\d])*)\\.)+[a-z]{2,}|'+ // domain name
+  '((\\d{1,3}\\.){3}\\d{1,3}))'+ // OR ip (v4) address
+  '(\\:\\d+)?(\\/[-a-z\\d%_.~+]*)*'+ // port and path
+  '(\\?[;&a-z\\d%_.~+=-]*)?'+ // query string
+  '(\\#[-a-z\\d_]*)?$','i'); // fragment locator
+  if(!pattern.test(str)) {
+          return false;
+
+  } else {
+          return true;
+
+  }
+}
 // override read function adding X-CSRFToken header
-OpenLayers.Protocol.SOS.v1_0_0.prototype.read = function(options) {    
+OpenLayers.Protocol.SOS.v1_0_0.prototype.read = function(options) {
     options = OpenLayers.Util.extend({}, options);
     OpenLayers.Util.applyDefaults(options, this.options || {});
     var response = new OpenLayers.Protocol.Response({requestType: "read"});
@@ -29,30 +44,33 @@ OpenLayers.SOSClient = OpenLayers.Class({
     legends: null,
     updateLegendTimeout: null,
     latestPosition: null,
+    events: null,
 
     // 52n bug on v4.0.0 and SOS1.0.0 need to check resultModel
     resultModel: 'om:Measurement',
 
     /**
-     * 
+     *
      */
     initialize: function (options) {
         OpenLayers.Util.extend(this, options);
+        this.events = new OpenLayers.Events(this);
         var params = {'service': 'SOS', 'request': 'GetCapabilities', 'acceptVersions': '1.0.0'};
         var paramString = OpenLayers.Util.getParameterString(params);
         url = OpenLayers.Util.urlAppend(this.url, paramString);
         OpenLayers.Request.GET({url: url,
-                                success: this.parseSOSCaps, 
-				scope: this,
-				async: false // metto async false altrimenti non riesco a controllare il caricamento da GXP
-			       });
-	
-
+                                success: this.parseSOSCaps,
+                                failure: this.onFailure,
+                                scope: this
+                               });
+    },
+    onFailure: function(){
+        this.events.triggerEvent("failure");
     },
     getRandomColor: function () {
-	var colorIndex;
-	var color
-	var colors = ['#33a02c', '#1f78b4', '#b2df8a', '#a6cee3', '#fb9a99', '#e31a1c', '#fdbf6f', '#ff7f00', '#cab2d6' ,'#6a3d9a', '#ffff99', '#b15928']
+        var colorIndex;
+        var color;
+        var colors = ['#33a02c', '#1f78b4', '#b2df8a', '#a6cee3', '#fb9a99', '#e31a1c', '#fdbf6f', '#ff7f00', '#cab2d6' ,'#6a3d9a', '#ffff99', '#b15928'];
 	// warning: global variable
 	// if(sosColorsIndex  === 'undefined'){
 	if(typeof sosColorsIndex == 'undefined'){
@@ -116,8 +134,8 @@ OpenLayers.SOSClient = OpenLayers.Class({
 	    }
 	}
 	return elements[0].url;
-    }, 
-    
+    },
+
     parseSOSCaps: function(response) {
         // cache capabilities for future use
         this.SOSCapabilities = this.capsformat.read(response.responseXML || response.responseText);
@@ -128,10 +146,12 @@ OpenLayers.SOSClient = OpenLayers.Class({
         //                               {scope: this, onSelect: this.onFeatureSelect});
         // this.map.addControl(this.ctrl);
         // this.ctrl.activate();
+        this.events.triggerEvent("loaded",
+                         {"capabilities": this.SOSCapabilities});
     },
-    
+
     /**
-     * 
+     *
      */
     getFois: function() {
         var result = [];
@@ -149,7 +169,7 @@ OpenLayers.SOSClient = OpenLayers.Class({
         }
         return result;
     },
-    
+
     getTitleForObservedProperty: function(property) {
         for (var name in this.SOSCapabilities.contents.offeringList) {
             var offering = this.SOSCapabilities.contents.offeringList[name];
@@ -189,9 +209,9 @@ OpenLayers.SOSClient = OpenLayers.Class({
             observedProperties: observedProperties,
             responseFormat: this.getResponseFormat()
         });
-        
+
         var timeperiodXml = this.getGmlTimeperiod(begin, end);
-        
+
         // a little rework due to missing timeperiod in OL-Format
         xml = xml.replace("xmlns:ogc=\"http://www.opengis.net/ogc\"", "xmlns:ogc=\"http://www.opengis.net/ogc\" xmlns:gml=\"http://www.opengis.net/gml\"");
         xml = xml.replace("<eventTime/>", timeperiodXml);
@@ -199,20 +219,20 @@ OpenLayers.SOSClient = OpenLayers.Class({
     },
 
     getGmlTimeperiod: function(begin, end) {
-        var timeperiod = "<eventTime>" + 
-                "<ogc:TM_During>" + 
-                "<ogc:PropertyName>om:samplingTime</ogc:PropertyName>" + 
-                "<gml:TimePeriod>" + 
-                "<gml:beginPosition>" + moment(begin).format() + "</gml:beginPosition>" + 
-                "<gml:endPosition>" + moment(end).format() + "</gml:endPosition>" + 
-                "</gml:TimePeriod>" + 
-                "</ogc:TM_During>" + 
+        var timeperiod = "<eventTime>" +
+                "<ogc:TM_During>" +
+                "<ogc:PropertyName>om:samplingTime</ogc:PropertyName>" +
+                "<gml:TimePeriod>" +
+                "<gml:beginPosition>" + moment(begin).format() + "</gml:beginPosition>" +
+                "<gml:endPosition>" + moment(end).format() + "</gml:endPosition>" +
+                "</gml:TimePeriod>" +
+                "</ogc:TM_During>" +
                 "</eventTime>";
-        
+
         return timeperiod;
     },
 
-    
+
     getResponseFormat: function(){
         if (!this.responseFormat) {
             for (format in this.SOSCapabilities.operationsMetadata.GetObservation.parameters.responseFormat.allowedValues) {
@@ -247,7 +267,7 @@ OpenLayers.SOSClient = OpenLayers.Class({
         }
 	return offerings;
     },
-    
+
     onFeatureSelect: function(feature) {
 	//alert(feature);
 	//console.log(feature);
@@ -259,7 +279,7 @@ OpenLayers.SOSClient = OpenLayers.Class({
         foiExplorer.show();
     },
 
-    getObservation: function(foiId, offering_id, begin, end, onSuccess){
+    getObservation: function(foiId, offering_id, observedProperty_id, begin, end, onSuccess){
         var offering = this.SOSCapabilities.contents.offeringList[offering_id];
         //c'e' un problema con array e extjs: vedi commento piu' avanti
         var observedProperties = {};
@@ -272,10 +292,12 @@ OpenLayers.SOSClient = OpenLayers.Class({
         // for(var i=0; i< offering.observedProperties.length; i++) {
 	//    observedProperties[i] = offering.observedProperties[i];
 	//}
-	if(offering.observedProperties.length>0){
-	    var observedProperties = {0: offering.observedProperties[0]}
-	}
+	//if(offering.observedProperties.length>0){
+	//  var observedProperties = {0: offering.observedProperties[0]}
+        //}
 
+	// ora e' passato come parametro alla funzione
+	var observedProperties = {0: observedProperty_id}
 
 	var xmlRequest = this.getObservationRequest(foiId, offering_id, observedProperties, begin,end, this.resultModel);
         OpenLayers.Request.POST({
@@ -294,11 +316,11 @@ OpenLayers.SOSClient = OpenLayers.Class({
 			// this.chartReload(); //TODO lanciare automaticamente il reload
 		    }
 		}
-		var output = this.obsformat.read(response.responseXML || response.responseText);		
+		var output = this.obsformat.read(response.responseXML || response.responseText);
 		//console.log(output);
 		onSuccess(offering, output);
 	    },
-	    
+
             failure: function(response) {
                 ("No data for charts...");
             },
@@ -308,19 +330,19 @@ OpenLayers.SOSClient = OpenLayers.Class({
     },
 
 
-    
+
     /**
-     * 
+     *
      */
     destroy: function () {
     },
 
     /**
-     * 
+     *
      */
     CLASS_NAME: "OpenLayers.SOSClient"
 });
-    
+
     PlotDataStore = Ext.extend(Ext.util.Observable, {
 	constructor: function(config){
 	    this.dataSeries = [];
@@ -331,7 +353,7 @@ OpenLayers.SOSClient = OpenLayers.Class({
             });
 
             this.listeners = config.listeners;
-	    
+
             PlotDataStore.superclass.constructor.call(this, config)
 	},
 	addSerie: function(data){
@@ -340,7 +362,7 @@ OpenLayers.SOSClient = OpenLayers.Class({
 	},
 	removeAll: function(){
 	    this.dataSeries = [];
-	    this.fireEvent('reload', this.dataSeries);	    
+	    this.fireEvent('reload', this.dataSeries);
 	},
 	removeSerie: function(serie_id){
             for(var i=0; i< this.dataSeries.length; i++) {
@@ -356,15 +378,15 @@ OpenLayers.SOSClient = OpenLayers.Class({
 	download: function(){
 	    // console.log(this.dataSeries);
 	    var de = new DataExporter();
-	    de.exportGrid(this.dataSeries);	    
+	    de.exportGrid(this.dataSeries);
 	}
-	
+
     });
 
 
 DataExporter = Ext.extend(Object, {
     dateFormat : 'Y-m-d g:i',
-    
+
     exportGrid: function(grid) {
         if (Ext.isIE) {
             this._ieToExcel(grid);
@@ -477,7 +499,7 @@ DataExporter = Ext.extend(Object, {
         if (window.ActiveXObject){
             var  xlApp, xlBook;
             try {
-                xlApp = new ActiveXObject("Excel.Application"); 
+                xlApp = new ActiveXObject("Excel.Application");
                 xlBook = xlApp.Workbooks.Add();
             } catch (e) {
                 Ext.Msg.alert('Error', 'For the export to work in IE, you have to enable a security setting called "Initialize and script ActiveX control not marked as safe" from Internet Options -> Security -> Custom level..."');
@@ -486,10 +508,10 @@ DataExporter = Ext.extend(Object, {
 
             xlBook.worksheets("Sheet1").activate;
             var XlSheet = xlBook.activeSheet;
-            xlApp.visible = true; 
+            xlApp.visible = true;
 
             this._ieGetGridData(grid, XlSheet);
-            XlSheet.columns.autofit; 
+            XlSheet.columns.autofit;
         }
     }
 });
@@ -497,18 +519,18 @@ DataExporter = Ext.extend(Object, {
 
 FoiExplorer = Ext.extend(Ext.Window, {
     constructor: function(config){
-        var today = new Date(), begin = new Date(), end = new Date();    
-	
-	this.timeRange = 5;
-        
+        var today = new Date(), begin = new Date(), end = new Date();
+
+	this.timeRange = 2;
+
         begin.setDate(today.getDate() - this.timeRange);
         this.dateRange = [begin, end];
 	this.frequency = 10;
 	this.interval = 3600;
-	
+
 	this.sosClient = config.sosClient;
 	this.foiId = config.foi.attributes.id
-	
+
 	// add listeners
         this.addEvents({
             //"addSerie" : true,
@@ -516,10 +538,10 @@ FoiExplorer = Ext.extend(Ext.Window, {
 	    //"reload": true
         });
         this.listeners = config.listeners;
-	
+
 	// configure window
         this.count = 0;
-        
+
         //reinit
         this.offeringsGridId = Ext.id();
         this.placeholderId = Ext.id();
@@ -529,7 +551,7 @@ FoiExplorer = Ext.extend(Ext.Window, {
 	var defaultConfig = this.configureSOSWindow();
 	Ext.apply(defaultConfig, config);
 	FoiExplorer.superclass.constructor.call(this, defaultConfig);
-	
+
 
 	// lo creo qui per avere lo scope: this
 	// create stores
@@ -548,17 +570,17 @@ FoiExplorer = Ext.extend(Ext.Window, {
 
 	//console.log(config.foi);
 	var offerings = this.sosClient.getOfferingsByFoi(config.foi);
-	//console.log(offerings);
 	for (var name in offerings) {
 	    this.addSensorRecord(offerings[name], name);
+	    //console.log(offerings[name].observedProperties);
 	}
 
 	this.enableRealTime(false);
-	
+
     },
     plot: null,
     chartOptions: {
-        series: { 
+        series: {
             lines: { show: true },
             points: { show: true, radius: 2 } ,
             stack: false
@@ -590,7 +612,8 @@ FoiExplorer = Ext.extend(Ext.Window, {
     },
     onSelectOffering: function(sm, rowIndex, record ){
         var offering_id = record.data.name;
-	
+	var observedProperty_id = record.data.observedProperty;
+	var observedProperty_label = record.data.observedPropertyLabel;
 	var begin;
 	var end;
 	if(!this.realTime){
@@ -602,7 +625,7 @@ FoiExplorer = Ext.extend(Ext.Window, {
 	    end = new Date();
             begin.setTime(now.getTime() - this.interval * 1000);
 	}
-	
+
 	//console.log(moment(begin).format());
 	//console.log(moment(end).format());
 
@@ -610,10 +633,10 @@ FoiExplorer = Ext.extend(Ext.Window, {
         this.chartMask.show();
 
 	var plotDataStore = this.plotDataStore;
-	this.sosClient.getObservation(this.foiId, offering_id, begin,end, 
+	this.sosClient.getObservation(this.foiId, offering_id, observedProperty_id, begin,end,
 				      function(offering, output){
 					  var rows = [];
-					  var label = offering.name + " = No Values";
+                                          var uom = "-";
 					  if (output.measurements.length > 0) {
 					      // a look-up object for different time formats
 					      var timeMap = {};
@@ -623,7 +646,12 @@ FoiExplorer = Ext.extend(Ext.Window, {
 						  var timestamp = timePosObj.getTime();
 						  rows.push([timestamp, parseFloat(output.measurements[i].result.value)]);
 					      }
-		    
+
+                                              // get uom from first record
+                                              if(output.measurements.length > 0){
+                                                  uom = output.measurements[0].result.uom;
+                                              }
+
 					      function sortfunction(a, b){
 						  if(a[0] > b[0]) {
 						      return 1;
@@ -634,6 +662,7 @@ FoiExplorer = Ext.extend(Ext.Window, {
 					      }
 					      rows.sort(sortfunction);
 					  }
+					  var label = observedProperty_label + " (" + uom + ") = No Values";
 					  plotDataStore.addSerie({data: rows, label: label, serie_id: offering_id});
 				      });
     },
@@ -641,8 +670,8 @@ FoiExplorer = Ext.extend(Ext.Window, {
 	var grid = Ext.getCmp(this.offeringsGridId);
 	this.plotDataStore.removeAll();
 
-	var selection= grid.getSelectionModel(); 
-	for(i=0;i < grid.store.getCount();i++){  
+	var selection= grid.getSelectionModel();
+	for(i=0;i < grid.store.getCount();i++){
             if(selection.isSelected(i)){
 		this.onSelectOffering(1, 1, grid.store.getAt(i));
 	    }
@@ -688,23 +717,35 @@ FoiExplorer = Ext.extend(Ext.Window, {
 	var a = date.format("YYYY-MM-DD HH:mm");
         return a;
     },
-    addSensorRecord: function(offering, name, time, lastvalue) {        
+    addSensorRecord: function(offering, name, time, lastvalue) {
         this.count++;
-	this.offeringsStore.add(
-	    this.getSensorRecord({
-		type: offering.name, 
-		name: name, 
-		time: time,
-		startPeriod: (offering.time && offering.time.timePeriod) ? this.getFormattedDateFromTimePos(offering.time.timePeriod.beginPosition) : '-',
-		endPeriod: (offering.time && offering.time.timePeriod) ? this.getFormattedDateFromTimePos(offering.time.timePeriod.endPosition) : '-',
-		lastvalue: lastvalue
-	    })
-	);
-    },    
+	for(var i=0; i< offering.observedProperties.length; i++) {
+	    //console.log(i);
+            //exclude phenomenonTime
+            if(offering.observedProperties[i] == 'http://www.opengis.net/def/property/OGC/0/PhenomenonTime'){
+                continue;
+            }
+            observedPropertyLabel = offering.observedProperties[i];
+	    this.offeringsStore.add(
+		this.getSensorRecord({
+		    type: offering.name,
+		    name: name,
+		    observedProperty: offering.observedProperties[i],
+		    observedPropertyLabel: observedPropertyLabel,
+		    time: time,
+		    startPeriod: (offering.time && offering.time.timePeriod) ? this.getFormattedDateFromTimePos(offering.time.timePeriod.beginPosition) : '-',
+		    endPeriod: (offering.time && offering.time.timePeriod) ? this.getFormattedDateFromTimePos(offering.time.timePeriod.endPosition) : '-',
+		    lastvalue: lastvalue
+		})
+	    );
+        };
+    },
     getSensorRecord: function(config){
 	Ext.apply({
 	    type: null,
 	    name: null,
+	    observedProperty: null,
+	    observedPropertyLabel: null,
 	    time: null,
 	    startPeriod: null,
 	    endPeriod: null,
@@ -713,6 +754,8 @@ FoiExplorer = Ext.extend(Ext.Window, {
 	var SensorRecord =  Ext.data.Record.create([
             {name: "type", type: "string"},
             {name: "name", type: "string"},
+            {name: "observedProperty", type: "string"},
+            {name: "observedPropertyLabel", type: "string"},
             {name: "time", type: "string"},
             {name: "startPeriod", type: "string"},
             {name: "endPeriod", type: "string"},
@@ -721,6 +764,8 @@ FoiExplorer = Ext.extend(Ext.Window, {
 	return new SensorRecord({
             type: config.type,
             name: config.name,
+            observedProperty: config.observedProperty,
+            observedPropertyLabel: config.observedPropertyLabel,
             time: config.time,
             startPeriod: config.startPeriod,
             endPeriod: config.endPeriod,
@@ -750,12 +795,12 @@ FoiExplorer = Ext.extend(Ext.Window, {
         $("#"+this.placeholderId).bind('plotpan', function (event, plot) {
             sos.initLegends();
         });
-        
+
         $("#"+this.placeholderId).bind('plotzoom', function (event, plot) {
             sos.initLegends();
         });
-        
-    },    
+
+    },
     updateLegend: function(){
         this.updateLegendTimeout = null;
         var pos = this.latestPosition;
@@ -772,7 +817,7 @@ FoiExplorer = Ext.extend(Ext.Window, {
             for (j = 0; j < series.data.length; ++j)
                 if (series.data[j][0] > pos.x)
                     break;
-            
+
             // now interpolate
             var y, p1 = series.data[j - 1], p2 = series.data[j];
             if (p1 == null)
@@ -781,7 +826,7 @@ FoiExplorer = Ext.extend(Ext.Window, {
                 y = p1[1];
             else
                 y = p1[1] + (p2[1] - p1[1]) * (pos.x - p1[0]) / (p2[0] - p1[0]);
-            
+
             this.legends.eq(i).text(series.label.replace(/=.*/, "= " + y.toFixed(3)));
         }
     },
@@ -791,16 +836,44 @@ FoiExplorer = Ext.extend(Ext.Window, {
             // store configs
             // autoDestroy: true,
             // reader configs
-            idIndex: 0,  
+            idIndex: 0,
             fields: [
 		{name: 'type'},
 		{name: 'name'},
+		{name: 'observedProperty'},
+		{name: 'observedPropertyLabel'},
 		{name: 'time'},
 		{name: 'startPeriod'},
 		{name: 'endPeriod'},
 		{name: 'lastvalue'}
             ]
 	});
+        this.offeringsStore.addListener('add', function(store, records, index){
+            var record = records[0];
+            var op = record.get('observedProperty');
+            if(ValidURL(op)){
+                var request = OpenLayers.Request.GET({
+                    url: op,
+                    success: function(request){
+                        var doc = null;
+                        if(!request.responseXML.documentElement) {
+                            var format = new OpenLayers.Format.XML();
+                            doc = format.read(request.responseText);
+                        } else {
+                            doc = request.responseXML;
+                        }
+                        var label = doc.getElementsByTagNameNS('http://www.w3.org/2004/02/skos/core#', 'altLabel');
+                        if(label){
+                            label = label[0].textContent;
+                        }
+                        if(label && label != ''){
+                            record.set('observedPropertyLabel', label);
+                        }
+                    },
+                    failure: function(request){}
+                });
+            }
+        }, this.offeringsStore);
         return {
             maximizable: true,
             width: 1000,
@@ -1031,7 +1104,8 @@ FoiExplorer = Ext.extend(Ext.Window, {
                             sortable: true
                         },
                         columns: [
-                            {id: 'type', header: 'Type', dataIndex: 'type'},
+                            //{id: 'type', header: 'Type', dataIndex: 'type'},
+			    {header: 'Observed property', dataIndex: 'observedPropertyLabel'},
                             {header: 'Start', dataIndex: 'startPeriod'},
                             {header: 'End', dataIndex: 'endPeriod'}//,
                             //{header: 'Time', dataIndex: 'time'},
@@ -1062,4 +1136,4 @@ FoiExplorer = Ext.extend(Ext.Window, {
             }]
         }
     }
-});
\ No newline at end of file
+});
